@@ -674,6 +674,14 @@ create_command_from_filename (FrArchive  *archive,
 		return (archive->command != NULL);
 	}
 
+	if (file_extension_is (filename, ".tar.lzma")
+	    || file_extension_is (filename, ".tzma")) {
+		archive->command = fr_command_tar_new (archive->process,
+						       filename,
+						       FR_COMPRESS_PROGRAM_LZMA);
+		return (archive->command != NULL);
+	}
+
 	if (file_extension_is (filename, ".tar.lzo")
 	    || file_extension_is (filename, ".tzo")) {
 		archive->command = fr_command_tar_new (archive->process,
@@ -763,6 +771,12 @@ create_command_from_filename (FrArchive  *archive,
 			return (archive->command != NULL);
 		}
 
+		if (file_extension_is (filename, ".lzma")) {
+			archive->command = fr_command_cfile_new (archive->process, filename, FR_COMPRESS_PROGRAM_LZMA);
+			archive->is_compressed_file = TRUE;
+			return (archive->command != NULL);
+		}
+
 		if (file_extension_is (filename, ".lzo")) {
 			archive->command = fr_command_cfile_new (archive->process, filename, FR_COMPRESS_PROGRAM_LZOP);
 			archive->is_compressed_file = TRUE;
@@ -2595,6 +2609,7 @@ archive_type_has_issues_deleting_non_empty_folders (FrArchive *archive)
 		|| (archive->command->file_type == FR_FILE_TYPE_TAR_BZ)
 		|| (archive->command->file_type == FR_FILE_TYPE_TAR_BZ2)
 		|| (archive->command->file_type == FR_FILE_TYPE_TAR_GZ)
+		|| (archive->command->file_type == FR_FILE_TYPE_TAR_LZMA)
 		|| (archive->command->file_type == FR_FILE_TYPE_TAR_LZOP)
 		|| (archive->command->file_type == FR_FILE_TYPE_TAR_COMPRESS));
 }
@@ -2796,8 +2811,6 @@ extract_in_chunks (FrCommand  *command,
 {
 	GList *scan;
 
-	fr_command_set_n_files (command, g_list_length (file_list));
-
 	if (file_list == NULL) {
 		fr_command_extract (command,
 				    file_list,
@@ -2936,6 +2949,7 @@ archive_type_has_issues_extracting_non_empty_folders (FrArchive *archive)
 		|| (archive->command->file_type == FR_FILE_TYPE_TAR_BZ)
 		|| (archive->command->file_type == FR_FILE_TYPE_TAR_BZ2)
 		|| (archive->command->file_type == FR_FILE_TYPE_TAR_GZ)
+		|| (archive->command->file_type == FR_FILE_TYPE_TAR_LZMA)
 		|| (archive->command->file_type == FR_FILE_TYPE_TAR_LZOP)
 		|| (archive->command->file_type == FR_FILE_TYPE_TAR_COMPRESS));
 }
@@ -3029,6 +3043,8 @@ fr_archive_extract_to_local (FrArchive  *archive,
 		file_list_created = TRUE;
 	}
 
+	fr_command_set_n_files (archive->command, g_list_length (file_list));
+
 	use_base_dir = ! ((base_dir == NULL)
 			  || (strcmp (base_dir, "") == 0)
 			  || (strcmp (base_dir, "/") == 0));
@@ -3042,6 +3058,7 @@ fr_archive_extract_to_local (FrArchive  *archive,
 		if (! extract_all && archive_type_has_issues_extracting_non_empty_folders (archive)) {
 			created_filtered_list = TRUE;
 			filtered = g_list_copy (file_list);
+			filtered = g_list_sort (filtered, (GCompareFunc) strcmp);
 			for (scan = filtered; scan; /* empty */) {  
 				gboolean changed = FALSE;
 				
@@ -3385,6 +3402,7 @@ fr_archive_utils__get_file_name_ext (const char *filename)
 		".iso",
 		".jar",
 		".lzh",
+		".lzma",
 		".lzo",
 		".rar",
 		".rpm",
@@ -3393,6 +3411,7 @@ fr_archive_utils__get_file_name_ext (const char *filename)
 		".tar.bz",
 		".tar.bz2",
 		".tar.gz",
+		".tar.lzma",
 		".tar.lzo",
 		".tar.Z",
 		".taz",
