@@ -48,15 +48,15 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:INT (/home/paolo/workspace/file-roller/src/fr-marshal.list:1) */
+/* VOID:INT (fr-marshal.list:1) */
 
-/* VOID:INT,POINTER (/home/paolo/workspace/file-roller/src/fr-marshal.list:2) */
+/* VOID:INT,POINTER (fr-marshal.list:2) */
 void
 fr_marshal_VOID__INT_POINTER (GClosure     *closure,
-                              GValue       *return_value,
+                              GValue       *return_value G_GNUC_UNUSED,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_POINTER) (gpointer     data1,
@@ -87,13 +87,13 @@ fr_marshal_VOID__INT_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER (/home/paolo/workspace/file-roller/src/fr-marshal.list:3) */
+/* VOID:POINTER (fr-marshal.list:3) */
 
-/* VOID:VOID (/home/paolo/workspace/file-roller/src/fr-marshal.list:4) */
+/* VOID:VOID (fr-marshal.list:4) */
 
-/* VOID:DOUBLE (/home/paolo/workspace/file-roller/src/fr-marshal.list:5) */
+/* VOID:DOUBLE (fr-marshal.list:5) */
 
-/* VOID:STRING (/home/paolo/workspace/file-roller/src/fr-marshal.list:6) */
+/* VOID:STRING (fr-marshal.list:6) */
 
-/* VOID:BOOL (/home/paolo/workspace/file-roller/src/fr-marshal.list:7) */
+/* VOID:BOOL (fr-marshal.list:7) */
 
