@@ -32,21 +32,18 @@
 #define OLD_RC_RECENT_FILE      ".file-roller/recents"
 #define OLD_RC_OPTIONS_DIR      ".file-roller/options"
 
+typedef enum {
+	FR_WINDOW_SORT_BY_NAME = 0,
+	FR_WINDOW_SORT_BY_SIZE = 1,
+	FR_WINDOW_SORT_BY_TYPE = 2,
+	FR_WINDOW_SORT_BY_TIME = 3,
+	FR_WINDOW_SORT_BY_PATH = 4
+} FRWindowSortMethod;
 
 typedef enum {
-	WINDOW_SORT_BY_NAME = 0,
-	WINDOW_SORT_BY_SIZE = 1,
-	WINDOW_SORT_BY_TYPE = 2,
-	WINDOW_SORT_BY_TIME = 3,
-	WINDOW_SORT_BY_PATH = 4
-} WindowSortMethod;
-
-
-typedef enum {
-	WINDOW_LIST_MODE_FLAT,
-	WINDOW_LIST_MODE_AS_DIR
-} WindowListMode;
-
+	FR_WINDOW_LIST_MODE_FLAT,
+	FR_WINDOW_LIST_MODE_AS_DIR
+} FRWindowListMode;
 
 typedef enum {
 	FR_COMPRESS_PROGRAM_NONE,
@@ -54,10 +51,10 @@ typedef enum {
 	FR_COMPRESS_PROGRAM_BZIP,
 	FR_COMPRESS_PROGRAM_BZIP2,
 	FR_COMPRESS_PROGRAM_COMPRESS,
+	FR_COMPRESS_PROGRAM_LZMA,
 	FR_COMPRESS_PROGRAM_LZOP
 } FRCompressProgram;
 
-
 typedef enum {
 	FR_COMPRESSION_VERY_FAST,
 	FR_COMPRESSION_FAST,
@@ -65,10 +62,10 @@ typedef enum {
 	FR_COMPRESSION_MAXIMUM
 } FRCompression;
 
-
 typedef enum {
 	FR_PROC_ERROR_NONE,
 	FR_PROC_ERROR_GENERIC,
+	FR_PROC_ERROR_COMMAND_ERROR,
 	FR_PROC_ERROR_COMMAND_NOT_FOUND,
 	FR_PROC_ERROR_EXITED_ABNORMALLY,
 	FR_PROC_ERROR_SPAWN,
@@ -76,14 +73,12 @@ typedef enum {
 	FR_PROC_ERROR_ASK_PASSWORD
 } FRProcErrorType;
 
-
 typedef struct {
 	FRProcErrorType  type;
 	int              status;
 	GError          *gerror;
 } FRProcError;
 
-
 typedef enum {
 	FR_FILE_TYPE_ACE,
 	FR_FILE_TYPE_AR,
@@ -99,6 +94,7 @@ typedef enum {
 	FR_FILE_TYPE_GZIP,
 	FR_FILE_TYPE_JAR,
 	FR_FILE_TYPE_LHA,
+	FR_FILE_TYPE_LZMA,
 	FR_FILE_TYPE_LZOP,
 	FR_FILE_TYPE_RAR,
 	FR_FILE_TYPE_RPM,
@@ -106,6 +102,7 @@ typedef enum {
 	FR_FILE_TYPE_TAR_BZ,
 	FR_FILE_TYPE_TAR_BZ2,
 	FR_FILE_TYPE_TAR_GZ,
+	FR_FILE_TYPE_TAR_LZMA,
 	FR_FILE_TYPE_TAR_LZOP,
 	FR_FILE_TYPE_TAR_COMPRESS,
 	FR_FILE_TYPE_STUFFIT,
@@ -116,7 +113,6 @@ typedef enum {
 	FR_FILE_TYPE_NULL
 } FRFileType;
 
-
 typedef struct {
 	FRFileType  id;
 	char       *ext;
@@ -124,7 +120,6 @@ typedef struct {
 	char       *name;
 } FRFileTypeDescription;
 
-
 typedef struct {
 	char       *command;
 	gboolean    can_open;
@@ -133,6 +128,5 @@ typedef struct {
 	FRFileType  file_type;
 } FRCommandDescription;
 
-
 #endif /* TYPEDEFS_H */
 
